@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # hmath
-# v.3.3.3
+# v.3.3.5
 # by caleb7023
 #
 #                                        ...(+uwXuuZuuZuuZZuZXA&J-..
@@ -66,7 +66,7 @@ hmath was developed to use advanced math functions in python.
 You can use complex numbers for most functions.
 
 # Version
-[v.3.3.4](https://caleb7023.hmath.pro/version/v-3-3-4)
+[v.3.3.5](https://caleb7023.hmath.pro/version/v-3-3-5)
 
 hmath is investigating whether the calculation of the function is correct and whether the calculation is efficient. 
 Please help us provide information on efficient calculation methods and whether the calculations are correct.
@@ -75,10 +75,9 @@ Please help us provide information on efficient calculation methods and whether
 
 [Feedback on hmath modules](https://caleb7023.hmath.pro/Feedback)
 """
-
+print("The function is being processed.")
 __corresponding_dictionary = {
     "B"                     : {},
-    "O"                     : {},
     "ln"                    : {},
     "rad"                   : {},
     "exp"                   : {},
@@ -119,15 +118,26 @@ __corresponding_dictionary = {
 def __memo(func):
     def memo(*args):
         global __corresponding_dictionary
-        if args in __corresponding_dictionary[func.__name__]:
-            ans = __corresponding_dictionary[func.__name__][args]
+        if func.__name__ != "dlist":
+            if args in __corresponding_dictionary[func.__name__]:
+                ans = __corresponding_dictionary[func.__name__][args]
+            else:
+                new_func = func
+                if len(args) == 1:
+                    ans = new_func(args[0])
+                if len(args) == 2:
+                    ans = new_func(args[0], args[1])
+                if len(args) == 3:
+                    ans = new_func(args[0], args[1], args[2])
+                __corresponding_dictionary[func.__name__][args] = ans
         else:
             new_func = func
             if len(args) == 1:
                 ans = new_func(args[0])
             if len(args) == 2:
                 ans = new_func(args[0], args[1])
-            __corresponding_dictionary[func.__name__][args] = ans
+            if len(args) == 3:
+                ans = new_func(args[0], args[1], args[2])
         return ans
     return memo
 
@@ -159,6 +169,8 @@ def __list(func):
                 return func(args[0])
             if len(args) == 2:
                 return func(args[0], args[1])
+            if len(args) == 3:
+                return func(args[0], args[1], args[2])
     return dlist
 
 def __pow(func):
@@ -526,28 +538,35 @@ def Pi(_roop_time, _first_value, _formula):
         ans *= eval(_formula)
     return ans
 
-@__memo
 @__list
+@__memo
 def reduction_of_fraction(_fr):
     """
     "reduction_of_fraction(x)" reduces the fraction x.
     """
     process = 1
-    if not(type(_fr.mole) == complex or type(_fr.deno) == complex):
-        while True:
-            process += 1
-            test = primality_test(process)
-            if test:
-                if _fr.mole / process % 1 == 0 and _fr.deno / process % 1 == 0:
-                    _fr     = fraction(_fr.mole / process, _fr.deno / process)
-                    process = 1
-            elif min(abs(_fr.mole) , abs(_fr.deno)) < process:
-                break
-        if _fr.deno == 1:
-            _fr = _fr.mole
-        elif _fr.deno == _fr.mole:
-            _fr = 1
-        return _fr
+    if type(_fr.mole) != complex and type(_fr.deno) != complex:
+        if _fr.mole < 0 and _fr.deno < 0:
+            _fr = reduction_of_fraction(abs(_fr))
+            return _fr
+        elif _fr.mole < 0 or _fr.deno < 0:
+            _fr = reduction_of_fraction(-_fr)
+            return _fr
+        else:
+            while True:
+                process += 1
+                test = primality_test(process)
+                if test:
+                    if _fr.mole / process % 1 == 0 and _fr.deno / process % 1 == 0:
+                        _fr     = fraction(_fr.mole / process, _fr.deno / process)
+                        process = 1
+                elif min(abs(_fr.mole) , abs(_fr.deno)) < process:
+                    break
+            if _fr.deno == 1:
+                _fr = _fr.mole
+            elif _fr.deno == _fr.mole:
+                _fr = 1
+            return _fr
     return _fr
 
 @__list
@@ -603,13 +622,8 @@ def prime_factorization(_n):
 
 @__list
 @__memo
-def B(_x, _y):
-    return Gamma(_x) * Gamma(_y) / Gamma(_x + _y)
-
-@__list
-@__memo
-def O(_x):
-    return 3 * _x + 4 * square_root(_x) + 10
+def B(_n):
+    n = _n / 2
 
 @__list
 @__memo
@@ -953,12 +967,10 @@ def acoth(_x, _n = 0):
     return atanh(1 / _x)
 
 @__list
-@__memo
 def radian(_θ):
     return _θ * 57.295779513082320876798154814105
 
 @__list
-@__memo
 def degrees(_θ):
     return _θ / 57.295779513082320876798154814105
 
@@ -967,3 +979,5 @@ def degrees(_θ):
 @__memo
 def polyGamma(_x, _n = 0):
     return Gamma(_x, "d") / Gamma(_x)
+
+B(300)
\ No newline at end of file
